const _ = require('lodash');
const { NotFoundException, NotAuthorizedException }  = require('lx-errors');
const { client } = require('lx-models');
const { getUser } = require('../handlers');
const session = require('../session');


module.exports = function(handler) {
  const name = handler.name;

  return function *(args) {
    const { Action, Permission } = client.getModels();
    const actionName = _.upperCase(name).replace(' ', '_');
    if (actionName !== 'CREATE_SESSION') {
      const sessionToken = args.sessionToken;

      let user;
      let roleName = (yield function *() {
        if (!sessionToken) {
          return 'guest';
        }
        try {
          const response = yield getUser({ sessionToken });
          user = response.result
          session.set('user', user);
          return user.roleName;
        } catch (err) {
          if (err instanceof NotFoundException) {
            return 'guest';
          } else {
            throw err;
          }
        }
      });

      const actionSuspended = yield Action.findOne({
        where: {
          name: actionName,
          isSuspended: true,
        },
      });
      if (actionSuspended) {
        throw new NotAuthorizedException();
      }

      const actionExists = (yield function *() {
        const count = yield Action.count({
          where: {
            name: actionName,
          }
        });
        return count > 0;
      });

      if (actionExists) {
        const permissions = yield Permission.findAll({
          where: {
            $or: [
              { roleName: roleName },
              { roleName: 'guest' },
            ],
            actionName,
            isSuspended: false,
          },
        });
        if (permissions.length === 0) {
          throw new NotAuthorizedException();
        }
      }
    }
    return yield handler(args);
  };
};

