const { NotFoundException } = require('lx-errors');
const Joi = require('lx-pjoi');
const evalModel = require('./evalModel');


function makeGet({ model, key, keyType, keys }) {
  key = key || 'id';
  keyType = keyType || 'number';
  keys = keys || { [key]: keyType };

  const getModel = function *(args) {
    model = evalModel(model);
    let result;
    // TODO: validate if the key provided are valid indexed fields
    // in the models
    for (const aKey in keys) {
      if ({}.hasOwnProperty.call(keys, aKey)) {
        result = yield model.findOne({
          where: { [aKey]: { $eq: args[aKey] } },
        });
        if (result !== null) {
          break;
        }
      }
    }
    if (!result) {
      throw new NotFoundException();
    }
    return {
      result,
    };
  };


  const joiValidations = {};
  for (const key in keys) {
    if ({}.hasOwnProperty.call(keys, key)) {
      joiValidations[key] = Joi[keys[key]]();
    }
  }
  getModel.schema = Joi.object().keys(
    joiValidations
  ).xor(Object.keys(joiValidations));

  return getModel;
}

module.exports = makeGet;

