const _ = require('lodash');
const jwt = require('jsonwebtoken');
const { NotFoundException, NotAuthorizedException }  = require('lx-errors');
const { client } = require('lx-models');
const getUser = require('./getUser');
const { sessionSecretKey, sessionExpiresIn } = require('../../config');


function *createSession(args) {
  const { User, Permission } = client.getModels();
  const { sessionToken, username, password } = args;

  let user;
  if (sessionToken) {
    const response = yield getUser({ sessionToken });
    user = response.result;
    if (!user) {
      throw new NotAuthorizedException('Session token is not valid!');
    }
  } else {
    const cleanedUsername = username.trim().toLowerCase();
    user = yield User.findOne({
      where: {
        $or: [
          { username: cleanedUsername },
          { email: cleanedUsername },
        ],
      },
    });
    if (!user) {
      throw new NotFoundException('Username is not found!');
    }
    if (!user.checkPassword(password)) {
      throw new NotAuthorizedException('Password does not match!');
    }
  }

  const permissions = yield Permission.findAll({
    where: {
      $or: [
        { roleName: user.roleName },
        { roleName: 'guest' },
      ],
    },
    order: ['roleName']
  });
  const allow = _.uniq(permissions.map(p => p.actionName)).sort();


  return {
    meta: {
      user,
      sessionToken: jwt.sign(
        { id: user.id }, 
        sessionSecretKey,
        { expiresIn: sessionExpiresIn }
      ),
      allow,
    },
  };
}

module.exports = createSession;

