const Joi = require('lx-pjoi');
const uuid = require('uuid');
const fetch = require('isomorphic-fetch');
const config = require('../../config');
const { servicesApiUrl, awsAcccessKey, awsSecretKey, awsBucket } = config;


function *getImageUploadUrl(args) {
  const { filename, contentType } = yield Joi.validate(args, getImageUploadUrl.schema);
  const splits = filename.split('.');
  const extension = splits[splits.length - 1].toLowerCase();
  const normalizeExtension = extension === 'jpeg' ? 'jpg' : extension;
  const key = (new Date()).valueOf() + '-' + uuid.v4() + '.' + normalizeExtension;
  const result = yield fetch(`${servicesApiUrl}/get-presigned-upload-url`, {
    method: 'POST',
    body: JSON.stringify({
      accessKey: awsAcccessKey,
      secretKey: awsSecretKey,
      bucket: awsBucket,
      key,
      contentType,
    })
  });
  const json = yield result.json();
  if (json.ok) {
    return {
      result: json.result,
    }
  }
  throw new Error(json);
};


getImageUploadUrl.schema = Joi.object().keys({
  filename: Joi.string().required(),
  contentType: Joi.string().regex(/^image\//).required(),
  contentLength: Joi.number().min(1*1024).max(20*1024*1024).required(),
});


module.exports = getImageUploadUrl;

