const requireDirectory = require('require-directory');
const makeList = require('../crud/makeList');
const makeGet = require('../crud/makeGet');
const makeRemove = require('../crud/makeRemove');
const config = require('../../config');
const handlers = requireDirectory(module);
const { queryDefaultLimit, sessionSecretKey, sessionExpiresIn } = config;

module.exports = Object.assign(
  handlers,
  {
    root: function *() { return { result: { uptime: new Date() } } },
    getCategory: makeGet({ model: 'Category', keys: { id: 'number', hierarchy: 'string' } }),
    getItem: makeGet({ model: 'Item' }),
    getCountry: makeList({ model: 'Country', keys: { code: 'string' } }),
    getLanguage: makeList({ model: 'Language', keys: { code: 'string' } }),
    getCurrency: makeList({ model: 'Currency', keys: { code: 'string' } }),
    getRole: makeList({ model: 'Role', keys: { name: 'string' } }),
    getAction: makeList({ model: 'Action', keys: { name: 'string' } }),
    getLog: makeList({ model: 'Log' }),
    listUsers: makeList({ model: 'User', queryDefaultLimit }),
    listWishlists: makeList({ model: 'Wishlist', queryDefaultLimit }),
    listCountries: makeList({ model: 'Country', queryDefaultLimit: null }),
    listCurrencies: makeList({ model: 'Currency', queryDefaultLimit: null }),
    listLanguages: makeList({ model: 'Language', queryDefaultLimit: null }),
    listRoles: makeList({ model: 'Role', queryDefaultLimit: null }),
    listPermissions: makeList({ model: 'Permission',  queryDefaultLimit: null }),
    listActions: makeList({ model: 'Action', queryDefaultLimit: null }),
    listLogs: makeList({ model: 'Log', queryDefaultLimit }),
  }
);

