const Joi = require('lx-pjoi');
const { client } = require('lx-models');


function *search(args) {
  const { Item, Category, User } = client.getModels();
  const { q } = yield Joi.validate(args, search.schema);
  const query = `%${q}%`;
  const [ items, categories, users ] = yield [
    Item.findAll({ limit: 6, where: { title: { $ilike: query }, status: { $in: ['APPROVED', 'SOLD'] }, isSuspended: false }, toRaw: true }),
    Category.findAll({ limit: 6, where: { hierarchy: { $ilike: query }, isSuspended: false }, toRaw: true }),
    User.findAll({ limit: 6, where: { roleName: 'seller', fullName: { $ilike: query }, isSuspended: false }, toRaw: true }),
  ];
  return {
    result: {
      items,
      categories,
      users,
    },
  };
}

search.schema = Joi.object().keys({
  q: Joi.string().trim().min(2),
});

module.exports = search;

