const { NotFoundException, ValidationErrorException } = require('lx-errors');
const Joi = require('lx-pjoi');
const { client } = require('lx-models');


function *updateItem(args) {
  const Item = client.getModels().Item;
  const input = args;
  // const input = yield Joi.validate(args, updateItem.schema);
  const item = yield Item.findOne({ where: { id: input.id } });

  if (!item) {
    throw NotFoundException();
  }

  if (yield Item.findOne({
    where: {
      id: { $ne: item.id },
      userId: input.userId,
      title: input.title,
      categoryId: input.categoryId,
    },
    raw: true
  })) {
    throw new ValidationErrorException('Another item with the same title under the same category has already been posted by you!');
  }

  // manually run hook as it is corrupted from sequelize
  const updatedItem = yield item.beforeValidate(Object.assign(item, input));
  const result = yield updatedItem.save();
  return {
    result: result.toJSON(),
  };
}

// updateItem.schema = Joi.object().keys({
//   id: Joi.number().required(),
//   sourceId: Joi.string().trim().max(255, 'utf8').allow(null),
//   sourceName: Joi.string().trim().max(255, 'utf8').lowercase().allow(null),
//   isSuspended: Joi.boolean().allow(null),
//   status: Joi.string().trim().allow('PENDING', 'APPROVED', 'REJECTED', 'SOLD', 'EXPIRED').allow(null),
//   isApproved: Joi.boolean().allow(null),
//   approvedBy: Joi.number().allow(null),
//   approvedAt: Joi.date().allow(null),
//   userId: Joi.number(),
//   countryCode: Joi.string().trim().uppercase().allow(null),
//   languageCode: Joi.string().trim().lowercase().allow(null),
//   categoryId: Joi.number(),
//   title: Joi.string().trim(),
//   expiredAt: Joi.date().allow(null),
//   description: Joi.string().trim(),
//   currencyCode: Joi.string().trim().uppercase().allow(null),
//   price: Joi.number().allow(null),
//   priceInUsd: Joi.number().allow(null),
//   exchangeRateAt: Joi.date().allow(null),
//   exchangeRateMultiplierToUsd: Joi.number().allow(null),
//   mainImageUrl: Joi.string().uri(),
//   otherImageUrls: Joi.array().items(Joi.string().uri()).allow(null),
//   buyNowUrl: Joi.string().uri().allow(null),
//   aerialLookUrl: Joi.string().uri().allow(null),
//   aerialLook3dUrl: Joi.string().uri().allow(null),
// }).with('sourceId', 'sourceName').with('price', 'currency');


module.exports = updateItem;

