const { NotFoundException, ValidationErrorException } = require('lx-errors');
const Joi = require('lx-pjoi');
const { client } = require('lx-models');


function *updateUser(args) {
  const User = client.getModels().User;
  const input = args;
  // const input = yield Joi.validate(args, updateUser.schema);
  const user = yield User.findOne({ where: { id: input.id } });

  if (!user) {
    throw NotFoundException();
  }

  if (input.email && (yield User.findOne({
    where: {
      id: { $ne: user.id },
      email: input.email
    },
    raw: true
  }))) {
    throw new ValidationErrorException('Email has already been used.');
  }

  if (input.companyRegNumber && (yield User.findOne({
    where: {
      id: { $ne: user.id },
      companyRegNumber: input.companyRegNumber
    },
    raw: true
  }))) {
    throw new ValidationErrorException('Company registration number exists already.');
  }

  // manually run hook as it is corrupted from sequelize
  const updatedUser = user.beforeValidate(Object.assign(user, input));
  const result = yield updatedUser.save();
  return {
    result: result.toJSON(),
  };
} 

// updateUser.schema = Joi.object().keys({
//   id: Joi.number().required(),
//   sourceId: Joi.string().trim().max(255, 'utf8'),
//   sourceName: Joi.string().trim().max(255, 'utf8').lowercase(),
//   isSuspended: Joi.boolean(),
//   roleName: Joi.string().trim().lowercase(),
//   email: Joi.string().trim().lowercase().min(5).max(127).email(),
//   companyAddress: Joi.string().trim(),
//   companyRegNumber: Joi.string().trim(),
//   companyLogoUrl: Joi.string().trim().uri(),
//   companyName: Joi.string().trim(),
//   companySummary: Joi.string().trim(),
//   contactDetails: Joi.string().trim(),
//   countryCode: Joi.string().trim().uppercase(),
//   currencyCode: Joi.string().trim().uppercase(),
//   firstName: Joi.string().trim().max(50, 'utf8'),
//   lastName: Joi.string().trim().max(50, 'utf8'),
//   languageCode: Joi.string().trim().lowercase(),
//   password: Joi.string().min(5),
//   phoneNumbers: Joi.array().items(Joi.string()),
//   socialFacebookUrl: Joi.string().uri(),
//   socialInstagramUlr: Joi.string().uri(),
//   socialPinterestUrl: Joi.string().uri(),
//   socialTwitterUrl: Joi.string().uri(),
//   websiteUrl: Joi.string().uri(),
// });

module.exports = updateUser;

